@@ -60,15 +60,6 @@ struct _CppJavaPlugin {
 	gboolean support_installed;
 	const gchar *current_language;
 
-	/* Adaptive indentation parameters */
-	gint param_tab_size;
-	gint param_use_spaces;
-	gint param_statement_indentation;
-	gint param_brace_indentation;
-	gint param_case_indentation;
-	gint param_label_indentation;
-	gboolean smart_indentation;
-
 	/* Assist */
 	CppJavaAssist *assist;
 	CppFileType filetype;
